using System;
using System.Collections.Generic;
using System.Text;
using VVVV.PluginInterfaces.V1;
using KeggAPI.WebService.Kegg;

namespace VVVV.Nodes
{
    public class SearchDrugByNameNode : BaseSoapClientPlugin<KEGG>,IPlugin
    {

        private IStringIn FPinInName;
        private IStringOut FPinInOutput;
        

        #region Plugin Information
        public static IPluginInfo PluginInfo
        {
            get
            {
                IPluginInfo Info = new PluginInfo();
                Info.Name = "SearchDrugByName";
                Info.Category = "Kegg";
                Info.Version = "";
                Info.Help = "Search for a drug in Kegg Database";
                Info.Bugs = "";
                Info.Credits = "";
                Info.Warnings = "";
                Info.Author = "vux";
                Info.Tags = "";

                //leave below as is
                System.Diagnostics.StackTrace st = new System.Diagnostics.StackTrace(true);
                System.Diagnostics.StackFrame sf = st.GetFrame(0);
                System.Reflection.MethodBase method = sf.GetMethod();
                Info.Namespace = method.DeclaringType.Namespace;
                Info.Class = method.DeclaringType.Name;
                return Info;
            }
        }
        #endregion

        protected override string DefaultUrl
        {
            get { return "http://soap.genome.jp/keggapi/request_v6.2.cgi"; }
        }

        protected override void OnPluginHostSet()
        {   
            this.FHost.CreateStringInput("Drug Name", TSliceMode.Single, TPinVisibility.True, out this.FPinInName);
            this.FPinInName.SetSubType("", false);

            this.FHost.CreateStringOutput("Output", TSliceMode.Dynamic, TPinVisibility.True, out this.FPinInOutput);
            this.FPinInOutput.SetSubType("", false);

        }

        protected override void OnConfigurate(IPluginConfig Input)
        {
            
        }

        protected override void OnEvaluate(int SpreadMax, bool settingschanged)
        {
            if (settingschanged || this.FPinInName.PinIsChanged)
            {
                string name;
                this.FPinInName.GetString(0, out name);

                if (name.Trim().Length > 0)
                {

                    string[] result = this.FServiceProxy.search_drugs_by_name(name);
                    this.FPinInOutput.SliceCount = result.Length;
                    for (int i = 0; i < result.Length; i++)
                    {
                        this.FPinInOutput.SetString(i, result[i]);
                    }
                }
                else
                {
                    this.FPinInOutput.SliceCount = 0;
                }
            }
        }


    }

}
